@@ -40,6 +40,7 @@
     OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
+import argparse
 import sys
 from os import path
 from codecs import open
@@ -56,12 +57,12 @@ except NameError:
     term_input = input
 
 
-all_envs = ['py26', 'py27', 'py32', 'py33', 'py34', 'py35', 'pypy', 'jython']
+all_envs = ['py26', 'py27', 'py32', 'py33', 'py34', 'py35', 'py36', 'pypy', 'jython']
 
 PROMPT_PREFIX = '> '
 
 QUICKSTART_CONF = '''\
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
@@ -181,14 +182,14 @@ What Python versions do you want to test against? Choices:
 
     print('''
 What command should be used to test your project -- examples:
-    - py.test
+    - pytest
     - python setup.py test
     - nosetests package.module
     - trial package.module''')
     do_prompt(d, 'commands', 'Command to run to test project', '{envpython} setup.py test')
 
     default_deps = ' '
-    if 'py.test' in d['commands']:
+    if any(c in d['commands'] for c in ['pytest', 'py.test']):
         default_deps = 'pytest'
     if 'nosetests' in d['commands']:
         default_deps = 'nose'
@@ -224,19 +225,24 @@ def generate(d, overwrite=True, silent=False):
 
     def write_file(fpath, mode, content):
         print('Creating file %s.' % fpath)
-        f = open(fpath, mode, encoding='utf-8')
         try:
-            f.write(content)
-        finally:
-            f.close()
+            with open(fpath, mode, encoding='utf-8') as f:
+                f.write(content)
+        except IOError:
+            print('Error writing file.')
+            raise
 
     sys.stdout.write('\n')
 
-    fpath = 'tox.ini'
+    fpath = path.join(d.get('path', ''), 'tox.ini')
 
     if path.isfile(fpath) and not overwrite:
         print('File %s already exists.' % fpath)
-        do_prompt(d, 'fpath', 'Alternative path to write tox.ini contents to', 'tox-generated.ini')
+        do_prompt(
+            d,
+            'fpath',
+            'Alternative path to write tox.ini contents to',
+            path.join(d.get('path', ''), 'tox-generated.ini'))
         fpath = d['fpath']
 
     write_file(fpath, 'w', conf_text)
@@ -245,20 +251,31 @@ def generate(d, overwrite=True, silent=False):
         return
     sys.stdout.write('\n')
     print('Finished: A tox.ini file has been created. For information on this file, '
-          'see http://tox.testrun.org/latest/config.html')
+          'see https://tox.readthedocs.io/en/latest/config.html')
     print('''
 Execute `tox` to test your project.
 ''')
 
 
-def main(argv=sys.argv):
-    d = {}
+def parse_args(argv):
+    parser = argparse.ArgumentParser(
+        description='Command-line script to quickly setup tox.ini for a Python project.'
+    )
+    parser.add_argument(
+        'root', type=str, nargs='?', default='.',
+        help='Custom root directory to write tox.ini to. Defaults to current directory.'
+    )
+    parser.add_argument('--version', action='version', version='%(prog)s ' + __version__)
 
-    if len(argv) > 3:
-        print('Usage: tox-quickstart [root]')
-        sys.exit(1)
-    elif len(argv) == 2:
-        d['path'] = argv[1]
+    args = argv[1:]
+    return parser.parse_args(args)
+
+
+def main(argv=sys.argv):
+    args = parse_args(argv)
+
+    d = {}
+    d['path'] = args.root
 
     try:
         ask_user(d)
@@ -268,8 +285,13 @@ def main(argv=sys.argv):
         return
 
     d = process_input(d)
-    generate(d, overwrite=False)
+    try:
+        generate(d, overwrite=False)
+    except Exception:
+        return 2
+
+    return 0
 
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
